@@ -262,7 +262,7 @@ gnutls_init (gnutls_session_t * session, gnutls_connection_end_t con_end)
   _gnutls_buffer_init (&(*session)->internals.application_data_buffer);
   _gnutls_buffer_init (&(*session)->internals.handshake_data_buffer);
   _gnutls_buffer_init (&(*session)->internals.handshake_hash_buffer);
-  _gnutls_buffer_init(&(*session)->internals.ia_data_buffer);
+  _gnutls_buffer_init (&(*session)->internals.ia_data_buffer);
 
   _gnutls_buffer_init (&(*session)->internals.record_send_buffer);
   _gnutls_buffer_init (&(*session)->internals.record_recv_buffer);
@@ -355,7 +355,7 @@ gnutls_deinit (gnutls_session_t session)
   _gnutls_free_datum (&session->connection_state.read_mac_secret);
   _gnutls_free_datum (&session->connection_state.write_mac_secret);
 
-  _gnutls_buffer_clear(&session->internals.ia_data_buffer);
+  _gnutls_buffer_clear (&session->internals.ia_data_buffer);
   _gnutls_buffer_clear (&session->internals.handshake_hash_buffer);
   _gnutls_buffer_clear (&session->internals.handshake_data_buffer);
   _gnutls_buffer_clear (&session->internals.application_data_buffer);
@@ -932,21 +932,14 @@ int
 gnutls_prf_raw (gnutls_session_t session,
 		size_t label_size,
 		const char *label,
-		size_t seed_size,
-		const char *seed,
-		size_t outsize,
-		char *out)
+		size_t seed_size, const char *seed, size_t outsize, char *out)
 {
   int ret;
 
   ret = _gnutls_PRF (session->security_parameters.master_secret,
 		     TLS_MASTER_SIZE,
 		     label,
-		     label_size,
-		     (opaque*) seed,
-		     seed_size,
-		     outsize,
-		     out);
+		     label_size, (opaque *) seed, seed_size, outsize, out);
 
   return ret;
 }
@@ -985,10 +978,7 @@ gnutls_prf (gnutls_session_t session,
 	    size_t label_size,
 	    const char *label,
 	    int server_random_first,
-	    size_t extra_size,
-	    const char *extra,
-	    size_t outsize,
-	    char *out)
+	    size_t extra_size, const char *extra, size_t outsize, char *out)
 {
   int ret;
   opaque *seed;
@@ -997,7 +987,7 @@ gnutls_prf (gnutls_session_t session,
   seed = gnutls_malloc (seedsize);
   if (!seed)
     {
-      gnutls_assert();
+      gnutls_assert ();
       return GNUTLS_E_MEMORY_ERROR;
     }
 
@@ -1006,19 +996,13 @@ gnutls_prf (gnutls_session_t session,
 	  session->security_parameters.client_random, TLS_RANDOM_SIZE);
   memcpy (seed + TLS_RANDOM_SIZE, server_random_first ?
 	  session->security_parameters.client_random :
-	  session->security_parameters.server_random,
-	  TLS_RANDOM_SIZE);
+	  session->security_parameters.server_random, TLS_RANDOM_SIZE);
 
   memcpy (seed + 2 * TLS_RANDOM_SIZE, extra, extra_size);
 
   ret = _gnutls_PRF (session->security_parameters.master_secret,
 		     TLS_MASTER_SIZE,
-		     label,
-		     label_size,
-		     seed,
-		     seedsize,
-		     outsize,
-		     out);
+		     label, label_size, seed, seedsize, outsize, out);
 
   gnutls_free (seed);
 
@@ -1033,15 +1017,15 @@ gnutls_prf (gnutls_session_t session,
  * session.  The pointer must not be modified or deallocated.
  *
  * If a client random value has not yet been established, the output
- * will be garbage, and in particular a %NULL return value should not
- * be expected.
+ * will be garbage; in particular, a %NULL return value should not be
+ * expected.
  *
  * Return value: pointer to client random.
  **/
 const char *
 gnutls_session_get_client_random (gnutls_session_t session)
 {
-  return (char*) session->security_parameters.client_random;
+  return (char *) session->security_parameters.client_random;
 }
 
 /**
@@ -1052,15 +1036,37 @@ gnutls_session_get_client_random (gnutls_session_t session)
  * session.  The pointer must not be modified or deallocated.
  *
  * If a server random value has not yet been established, the output
- * will be garbage, and in particular a %NULL return value should not
- * be expected.
+ * will be garbage; in particular, a %NULL return value should not be
+ * expected.
  *
  * Return value: pointer to server random.
  **/
 const char *
 gnutls_session_get_server_random (gnutls_session_t session)
 {
-  return (char*) session->security_parameters.server_random;
+  return (char *) session->security_parameters.server_random;
+}
+
+/**
+ * gnutls_session_get_master_secret - get the session's master secret value
+ * @session: is a #gnutls_session_t structure.
+ *
+ * Return a pointer to the 48-byte master secret in the session.  The
+ * pointer must not be modified or deallocated.
+ *
+ * If a master secret value has not yet been established, the output
+ * will be garbage; in particular, a %NULL return value should not be
+ * expected.
+ *
+ * Consider using gnutls_prf() rather than extracting the master
+ * secret and use it to derive further data.
+ *
+ * Return value: pointer to master secret.
+ **/
+const char *
+gnutls_session_get_master_secret (gnutls_session_t session)
+{
+  return (char *) session->security_parameters.master_secret;
 }
 
 /**
