@@ -232,7 +232,7 @@ _gnutls_x509_crt_get_extension_oid (gnutls_x509_crt_t cert,
 	    {
 	      len = strlen (extnID) + 1;
 
-	      if (*sizeof_oid < (uint) len)
+	      if (*sizeof_oid < (unsigned) len)
 		{
 		  *sizeof_oid = len;
 		  gnutls_assert ();
@@ -455,12 +455,12 @@ _gnutls_x509_crt_set_extension (gnutls_x509_crt_t cert,
  * extension.
  */
 int
-_gnutls_x509_ext_extract_keyUsage (uint16 * keyUsage,
+_gnutls_x509_ext_extract_keyUsage (uint16_t * keyUsage,
 				   opaque * extnValue, int extnValueLen)
 {
   ASN1_TYPE ext = ASN1_TYPE_EMPTY;
   int len, result;
-  uint8 str[2];
+  uint8_t str[2];
 
   str[0] = str[1] = 0;
   *keyUsage = 0;
@@ -596,11 +596,11 @@ _gnutls_x509_ext_gen_basicConstraints (int CA, gnutls_datum_t * der_ext)
  * Use an ORed SEQUENCE of GNUTLS_KEY_* for usage.
  */
 int
-_gnutls_x509_ext_gen_keyUsage (uint16 usage, gnutls_datum_t * der_ext)
+_gnutls_x509_ext_gen_keyUsage (uint16_t usage, gnutls_datum_t * der_ext)
 {
   ASN1_TYPE ext = ASN1_TYPE_EMPTY;
   int result;
-  uint8 str[2];
+  uint8_t str[2];
 
   result = asn1_create_element (_gnutls_get_pkix (), "PKIX1.KeyUsage", &ext);
   if (result != ASN1_SUCCESS)
@@ -835,7 +835,7 @@ _gnutls_x509_ext_gen_crl_dist_points (gnutls_x509_subject_alt_name_t
   ASN1_TYPE ext = ASN1_TYPE_EMPTY;
   gnutls_datum_t gnames = { NULL, 0 };
   int result;
-  uint8 reasons[2];
+  uint8_t reasons[2];
 
   reasons[0] = reason_flags & 0xff;
   reasons[1] = reason_flags >> 8;
