@@ -341,7 +341,7 @@ gnutls_pkcs7_get_crt_raw (gnutls_pkcs7_t pkcs7,
 
       end = end - start + 1;
 
-      if ((uint) end > *certificate_size)
+      if ((unsigned) end > *certificate_size)
 	{
 	  *certificate_size = end;
 	  result = GNUTLS_E_SHORT_MEMORY_BUFFER;
@@ -452,7 +452,7 @@ gnutls_pkcs7_export (gnutls_pkcs7_t pkcs7,
 static int
 create_empty_signed_data (ASN1_TYPE pkcs7, ASN1_TYPE * sdata)
 {
-  uint8 one = 1;
+  uint8_t one = 1;
   int result;
 
   *sdata = ASN1_TYPE_EMPTY;
@@ -785,7 +785,7 @@ gnutls_pkcs7_get_crl_raw (gnutls_pkcs7_t pkcs7,
 
   end = end - start + 1;
 
-  if ((uint) end > *crl_size)
+  if ((unsigned) end > *crl_size)
     {
       *crl_size = end;
       result = GNUTLS_E_SHORT_MEMORY_BUFFER;
