@@ -1068,7 +1068,7 @@ gnutls_x509_crt_get_key_usage (gnutls_x509_crt_t cert,
 {
   int result;
   gnutls_datum_t keyUsage;
-  uint16 _usage;
+  uint16_t _usage;
 
   if (cert == NULL)
     {
@@ -1702,7 +1702,7 @@ gnutls_x509_crt_get_crl_dist_points (gnutls_x509_crt_t cert,
   int len;
   char num[MAX_INT_DIGITS];
   gnutls_x509_subject_alt_name_t type;
-  uint8 reasons[2];
+  uint8_t reasons[2];
 
   if (cert == NULL)
     {
