@@ -194,28 +194,9 @@ initialize_tls_session (void)
 
   gnutls_credentials_set (session, GNUTLS_CRD_PSK, server_pskcred);
 
-  gnutls_dh_set_prime_bits (session, DH_BITS);
-
   return session;
 }
 
-static gnutls_dh_params_t dh_params;
-
-static int
-generate_dh_params (void)
-{
-
-  /* Generate Diffie Hellman parameters - for use with DHE
-   * kx algorithms. These should be discarded and regenerated
-   * once a day, once a week or once a month. Depending on the
-   * security requirements.
-   */
-  gnutls_dh_params_init (&dh_params);
-  gnutls_dh_params_generate2 (dh_params, DH_BITS);
-
-  return 0;
-}
-
 static int
 pskfunc (gnutls_session_t session, const char *username, gnutls_datum_t * key)
 {
